# eric7.WebBrowser.AutoScroll.FrameScroller

Module implementing an object to scroll a web page.

### Global Attributes

None

### Classes

FrameScroller | Class implementing a web page scroller object.

### Functions

None

## FrameScroller

Class implementing a web page scroller object.

### Derived from

QObject

### Class Attributes

None

### Class Methods

None

### Methods

FrameScroller | Constructor
__scrollStep | Private slot to scroll one step.
scrollDivider | Public method to get the current scroll divider value.
setPage | Public method to set the web page to be scrolled.
setScrollDivider | Public method to set the scroll divider value.
startScrolling | Public method to start scrolling.
stopScrolling | Public method to stop scrolling.

### Static Methods

None

#### FrameScroller (Constructor)

FrameScroller(parent=None)

Constructor

parent (QObject)
  reference to the parent object

#### FrameScroller.__scrollStep

__scrollStep()

Private slot to scroll one step.

#### FrameScroller.scrollDivider

scrollDivider()

Public method to get the current scroll divider value.

Return:
  scroll divider

Return Type:
  float

#### FrameScroller.setPage

setPage(page)

Public method to set the web page to be scrolled.

page (WebBrowserPage)
  page to be scrolled

#### FrameScroller.setScrollDivider

setScrollDivider(divider)

Public method to set the scroll divider value.

divider (float)
  scroll divider

#### FrameScroller.startScrolling

startScrolling(lengthX, lengthY)

Public method to start scrolling.

lengthX (int)
  X distance from scroll indicator
lengthY (int)
  Y distance from scroll indicator

#### FrameScroller.stopScrolling

stopScrolling()

Public method to stop scrolling.

Up